@@ -43,19 +43,20 @@ _VT = TypeVar("_VT")
 JsonObjMutableMapping = MutableMapping[str, _VT]
 
 __all__ = (
-    "JsonObj",
-    "JsonDict",
-    "JsonObjMutableMapping",
-    "stringify",
-    "parse",
-    "jsonify",
     "JSON",
-    "UNDEFINED",
-    "undefined",
-    "Null",
-    "null",
     "JSONModuleCls",
+    "JsonDict",
+    "JsonObj",
+    "JsonObjMutableMapping",
     "JsonObjT",
+    "Null",
+    "UNDEFINED",
+    "jsonify",
+    "null",
+    "objectify",
+    "parse",
+    "stringify",
+    "undefined",
 )
 
 _JsonObjMutableMapping_attrs = set(dir(JsonObjMutableMapping))
@@ -285,6 +286,16 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
             )
         return self.__setitem__(attr, value)
 
+    def __setitem(self, key: _KT, value: _VT, identifier: bool = False) -> None:
+        if is_int(key):
+            self._data[str(key)] = value
+            return None
+        if identifier and not is_identifier(key):
+            raise ValueError(
+                f"Invalid key: ({key}).\n" f"Key(s) is not a valid python identifier"
+            )
+        self._data[key] = value
+
     def __setitem__(self, key: _KT, value: _VT) -> None:
         """Set JsonObj item with 'key' to 'value'
 
@@ -312,14 +323,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
             JsonObj(**{'a': 123, 'b': 321, '123': 'a', '456': 'a'})
 
         """
-        if is_int(key):
-            self._data[str(key)] = value
-            return None
-        if not is_identifier(key):
-            raise ValueError(
-                f"Invalid key: ({key}).\n" f"Key(s) is not a valid python identifier"
-            )
-        self._data[key] = value
+        self.__setitem(key, value, identifier=False)
 
     def __getattr__(self, item: _KT) -> Any:
         """Return an attr
@@ -739,7 +743,7 @@ class JsonObj(MutableMapping[str, _VT], Generic[_VT]):
             [
                 type(self).__name__,
                 "(**{\n    ",
-                pformat(self.to_dict(), width=_width)[1:-1].replace("\n", "\n   "),
+                pformat(self.eject(), width=_width)[1:-1].replace("\n", "\n   "),
                 "\n})",
             ]
         ).replace("JsonObj(**{}),", "{},")
@@ -1038,6 +1042,12 @@ def as_json_obj(value: Union[JsonObj[_VT], Dict[_KT, _VT]]) -> JsonObj[_VT]:
     return value
 
 
+def objectify(value: Union[JsonObj[_VT], Dict[_KT, _VT]]) -> JsonObj[_VT]:
+    if isinstance(value, dict):
+        return JsonObj(value)
+    return value
+
+
 @overload
 def jsonify(value: JsonPrimitiveT) -> JsonPrimitiveT:
     ...
@@ -1093,7 +1103,7 @@ class JSONMeta(type):
     """Meta type for use by JSON class to allow for static `__call__` method"""
 
     @staticmethod
-    def __call__(value: Optional[Any] = None) -> Any:  # type: ignore[override]
+    def __call__(value: Optional[Any] = None) -> Any:
         if value is None:
             value = {}
         return jsonify(value)
@@ -1281,6 +1291,8 @@ class JSON(metaclass=JSONMeta):
         """Alias for jsonbourne.core.unjsonify"""
         return unjsonify(value)
 
+    objectify = staticmethod(objectify)
+
 
 class JSONModuleCls(ModuleType, JSON):
     @staticmethod
